<?php
add_action( 'customize_register', 'berkeley_customize_register_content_setting' );
function berkeley_customize_register_content_setting( $wp_customize ) {
    $wp_customize->add_panel( 'berkeley_content_panel',
        array(
            'priority'       => 40,
            'capability'     => 'edit_theme_options',
            'title'          => __('Content Settings','berkeley'),
        )
    );

    $wp_customize->add_section('berkeley_design_options',
        array(
            'title'     => __('Blog Layout','berkeley'),
            'priority'  => 5,
            'panel'     => 'berkeley_content_panel'
        )
    );

    $wp_customize->add_setting('berkeley_blog_layout',
        array(
            'sanitize_callback' => 'berkeley_sanitize_blog_layout',
            'default'           => 'grid'
        )
    );

    function berkeley_sanitize_blog_layout( $input ) {
        if ( in_array($input, array('grid','grid_2_column','grid_3_column','berkeley') ) )
            return $input;
        else
            return '';
    }

    $wp_customize->add_control('berkeley_blog_layout',
        array(
            'label' => __('Select Layout','berkeley'),
            'settings' => 'berkeley_blog_layout',
            'section'  => 'berkeley_design_options',
            'type' => 'select',
            'choices' => array(
                'berkeley' => __('Berkeley Theme Layout','berkeley'),
                'grid' => __('Default Layout','berkeley'),
                'grid_2_column' => __('Grid - 2 Column','berkeley'),
                'grid_3_column' => __('Grid - 3 Column','berkeley'),

            )
        )
    );

    $wp_customize->add_section('berkeley_sidebar_options',
        array(
            'title'     => __('Sidebar Layout','berkeley'),
            'priority'  => 10,
            'panel'     => 'berkeley_content_panel'
        )
    );

    $wp_customize->add_setting('berkeley_disable_sidebar',
        array(
            'sanitize_callback' => 'berkeley_sanitize_checkbox',
            'default'  => true
        )
    );

    $wp_customize->add_control('berkeley_disable_sidebar',
        array(
            'settings' => 'berkeley_disable_sidebar',
            'label'    => __( 'Disable Sidebar Everywhere.','berkeley' ),
            'section'  => 'berkeley_sidebar_options',
            'type'     => 'checkbox',
        )
    );

    $wp_customize->add_setting('berkeley_disable_sidebar_home',
        array(
            'sanitize_callback' => 'berkeley_sanitize_checkbox',
            'default'  => true
        )
    );

    $wp_customize->add_control('berkeley_disable_sidebar_home',
        array(
            'settings' => 'berkeley_disable_sidebar_home',
            'label'    => __( 'Disable Sidebar on Home/Blog.','berkeley' ),
            'section'  => 'berkeley_sidebar_options',
            'type'     => 'checkbox',
            'active_callback' => 'berkeley_show_sidebar_options',
        )
    );

    $wp_customize->add_setting('berkeley_disable_sidebar_front',
        array(
            'sanitize_callback' => 'berkeley_sanitize_checkbox',
            'default'  => true
        )
    );

    $wp_customize->add_control('berkeley_disable_sidebar_front',
        array(
            'settings' => 'berkeley_disable_sidebar_front',
            'label'    => __( 'Disable Sidebar on Front Page.','berkeley' ),
            'section'  => 'berkeley_sidebar_options',
            'type'     => 'checkbox',
            'active_callback' => 'berkeley_show_sidebar_options',
        )
    );

    $wp_customize->add_setting('berkeley_sidebar_width',
        array(
            'default' => 4,
            'sanitize_callback' => 'berkeley_sanitize_positive_number'
        )
    );

    $wp_customize->add_control('berkeley_sidebar_width',
        array(
            'settings' => 'berkeley_sidebar_width',
            'label'    => __( 'Sidebar Width','berkeley' ),
            'description' => __('Min: 25%, Default: 33%, Max: 40%','berkeley'),
            'section'  => 'berkeley_sidebar_options',
            'type'     => 'range',
            'active_callback' => 'berkeley_show_sidebar_options',
            'input_attrs' => array(
                'min'   => 3,
                'max'   => 5,
                'step'  => 1,
                'class' => 'sidebar-width-range',
                'style' => 'color: #0a0',
            ),
        )
    );

    function berkeley_show_sidebar_options($control) {

        $option = $control->manager->get_setting('berkeley_disable_sidebar');
        return $option->value() == false ;

    }

    $wp_customize-> add_section('berkeley_custom_footer',
        array(
            'title'			=> __('Custom Footer Text','berkeley'),
            'description'	=> __('Enter your Own Copyright Text.','berkeley'),
            'priority'		=> 20,
            'panel'			=> 'berkeley_content_panel'
        )
    );

    $wp_customize->add_setting('berkeley_footer_text',
        array(
            'default'		=> '',
            'sanitize_callback'	=> 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('berkeley_footer_text',
        array(
            'section' => 'berkeley_custom_footer',
            'settings' => 'berkeley_footer_text',
            'type' => 'text'
        )
    );

    $wp_customize->add_section('berkeley_post_layout',
        array(
            'title'     => __('Post Layout','berkeley'),
            'priority'  => 15,
            'panel'     => 'berkeley_content_panel'
        )
    );

    $wp_customize->add_setting('berkeley_post_layout_style',
        array(
            'default'		=> 'default',
            'sanitize_callback' => 'berkeley_sanitize_post_layout'
        )
    );
    $wp_customize->add_control('berkeley_post_layout_style',
        array(
            'section' => 'berkeley_post_layout',
            'settings' => 'berkeley_post_layout_style',
            'label' => __('Select an style', 'berkeley'),
            'type' => 'select',
            'choices' => array(
                'default' => __('Default', 'berkeley'),
                'style1' => __('Style 1', 'berkeley'),
            )
        )
    );

    function berkeley_sanitize_post_layout( $input ) {
        if ( in_array($input, array('default','style1') ) )
            return $input;
        else
            return '';
    }

}