<?php
/*
 * @package berkeley, Copyright Shiv Kumar, shivink.com
 * This file contains Custom Theme Related Functions.
 */
/*
* @package madhat, Copyright Shiv Kumar, shivink.com
* This file contains Custom Theme Related Functions.
*/
//Import Admin Modules
get_template_part('/framework/main_modules/admin_styles');
get_template_part( '/framework/main_modules/register_styles');
get_template_part('/framework/main_modules/register_widgets');
get_template_part('/framework/main_modules/theme_setup');
get_template_part('/framework/main_modules/excerpt_length');
get_template_part('/framework/main_modules/exclude_single_post');

/*
** Walkers for Navigation menus
*/ 
class Berkeley_Menu_With_Description extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="fa ' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_url( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '<br /><span class="menu-desc">' . $item->description . '</span>';
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}

class Berkeley_Menu_With_Icon extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="fa ' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_url( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}


/*
** Function to check if Sidebar is enabled on Current Page 
*/

function berkeley_load_sidebar() {
	$load_sidebar = true;
	if ( get_theme_mod('berkeley_disable_sidebar', true) ) :
		$load_sidebar = false;
	elseif( get_theme_mod('berkeley_disable_sidebar_home',true) && is_home() )	:
		$load_sidebar = false;
	elseif( get_theme_mod('berkeley_disable_sidebar_front',true) && is_front_page() ) :
		$load_sidebar = false;
	endif;
	
	return  $load_sidebar;
}

/*
** Add Body Class
*/
add_filter( 'body_class', 'berkeley_body_class' );
function berkeley_body_class( $classes ) {
	
	$sidebar_class_name =  berkeley_load_sidebar() ? "sidebar-enabled" : "sidebar-disabled" ;
    return array_merge( $classes, array( $sidebar_class_name ) );   
}


/*
**	Determining Sidebar and Primary Width
*/
add_action('berkeley_primary-width', 'berkeley_primary_class');
function berkeley_primary_class() {
	$sw = esc_html(get_theme_mod('berkeley_sidebar_width',4));
	$class = "col-md-".(12-$sw);
	
	if ( !berkeley_load_sidebar() ) 
		$class = "col-md-12";
	
	echo $class;
}

add_action('berkeley_secondary-width', 'berkeley_secondary_class');
function berkeley_secondary_class() {
	$sw = esc_html(get_theme_mod('berkeley_sidebar_width',4));
	$class = "col-md-".$sw;
	
	echo $class;
}


/*
**	Helper Function to Convert Colors
*/
function berkeley_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);
   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}
function berkeley_fade($color, $val) {
	return "rgba(".berkeley_hex2rgb($color).",". $val.")";
}


/*
** Function to Get Theme Layout 
*/
add_action('berkeley_blog_layout', 'berkeley_get_blog_layout');
function berkeley_get_blog_layout(){
	$ldir = 'framework/custom-contents/content';
	if (get_theme_mod('berkeley_blog_layout') ) :
		get_template_part( $ldir , get_theme_mod('berkeley_blog_layout') );
	else :
		get_template_part( $ldir ,'berkeley');	
	endif;	
}

