<?php
/* 
**   Custom Modifcations in CSS depending on user settings.
*/
add_action('wp_enqueue_scripts', 'berkeley_custom_css_mods');
function berkeley_custom_css_mods() {

	$custom_css = "";

    if (!is_home() && is_front_page()) :
        if ( get_theme_mod('berkeley_content_font_size') ) :
            $size = (get_theme_mod('berkeley_content_font_size'));
            $custom_css .= "#primary-mono .entry-default-content { font-size:".$size.";}";
        endif;
    endif;

    if (get_theme_mod('berkeley_parallax_background_image') != '') :
        $image = get_theme_mod('berkeley_parallax_background_image');
        $custom_css .= "#parallax {
                    	background-image: url('" . $image . "');
                        background-size: cover;
                        background-attachment:fixed;
                        color: white;
                }";
    else:
        $custom_css .="#parallax { background: #efefef; }";
    endif;

	if ( get_theme_mod('berkeley_disable_active_nav') ) :
		$custom_css .= "#site-navigation ul .current_page_item > a, #site-navigation ul .current-menu-item > a, #site-navigation ul .current_page_ancestor > a { border:none; background: inherit; }"; 
	endif;
	
	if ( get_theme_mod('berkeley_center_logo') ) :
		
		$custom_css .= "#masthead #text-title-desc, #masthead #site-logo { float: none; } .site-branding { text-align: center; } #text-title-desc { display: inline-block; }";
		
	endif;
	
	if ( get_theme_mod('berkeley_center_logo') && !get_theme_mod('berkeley_branding_below_logo') ) :
		$custom_css .= ".site-branding #text-title-desc { text-align: left; }";
	endif;
	
	if ( get_theme_mod('berkeley_center_logo') && !get_theme_mod('berkeley_logo') ) :
		$custom_css .= ".site-branding #text-title-desc { text-align: center; }";
	endif;
	
	if ( !get_theme_mod('berkeley_center_logo') ) :
		$custom_css .= "#masthead #site-logo img { transform-origin: left; }";
	endif;	

	
	if ( get_background_color() ) {
		$custom_css .= "#social-search .searchform:before { border-left-color: #".get_background_color()." }";
		$custom_css .= "#social-search .searchform, #social-search .searchform:after { background: #".get_background_color()." }";
	}
	
	if ( get_theme_mod('berkeley_title_font','HIND') ) :
		$custom_css .= ".title-font, h1, h2 { font-family: ".esc_html(get_theme_mod('berkeley_title_font'))."; }";
	endif;
	
	if ( get_theme_mod('berkeley_body_font','Open Sans') ) :
		$custom_css .= "body { font-family: ".esc_html(get_theme_mod('berkeley_body_font'))."; }";
	endif;
	
	if (get_header_image()) 
		$custom_css .= '#masthead { padding-bottom: 20px; }';
	
	if ( get_header_textcolor() ) :
		$custom_css .= "#masthead h1.site-title a { color: #".get_header_textcolor()."; }";
	endif;
	
	
	if ( get_theme_mod('berkeley_header_desccolor','#000') ) :
		$custom_css .= "#masthead h2.site-description { color: ".esc_html(get_theme_mod('berkeley_header_desccolor','#000'))."; }";
	endif;
	
	
	if ( !display_header_text() ) :
		$custom_css .= "#masthead .site-branding #text-title-desc { display: none !important; }";
	endif;
	
	if ( berkeley_load_sidebar() ) :
		$custom_css .= ".berkeley { padding: 20px 20px; }";
	endif;
	
	if ( get_theme_mod('berkeley_logo_resizer') ) :
		$val = esc_html(get_theme_mod('berkeley_logo_resizer'))/100;
		$custom_css .= "#masthead #site-logo img { transform: scale(".$val."); -webkit-transform: scale(".$val."); -moz-transform: scale(".$val."); -ms-transform: scale(".$val."); }";
		endif;

    if (get_theme_mod('berkeley_fpage_background_img') != ''):
        $imagem = get_theme_mod('berkeley_fpage_background_img');
        $custom_css .= "#fpages {
                    	background-image: url('" . $imagem . "') !important;
                        background-size: cover;
                }";
    endif;
    
    if(get_theme_mod('berkeley_content_page_post_fontsize_set')):
        $val = get_theme_mod('berkeley_content_page_post_fontsize_set');
        if($val=='small'):
            $custom_css .= "#primary-mono .entry-default-content{ font-size:12px;}";
        elseif ($val=='medium'):
            $custom_css .= "#primary-mono .entry-default-content{ font-size:16px;}";
        elseif ($val=='large'):
            $custom_css .= "#primary-mono .entry-default-content{ font-size:18px;}";
        elseif ($val=='extra-large'):
            $custom_css .= "#primary-mono .entry-default-content{ font-size:20px;}";
        endif;
    else:
        $custom_css .= "#primary-mono .entry-default-content{ font-size:14px;}";
    endif;

    if (get_theme_mod('berkeley_fsec_background_img') != ''):
        $imagen = get_theme_mod('berkeley_fpage_background_img');
        $custom_css .= "#footer-area {
                    	background-image: url('" . $imagen . "') !important;
                        background-size: cover;
                }";
    endif;

	wp_add_inline_style( 'berkeley-main-style', wp_strip_all_tags($custom_css) );
	
}